@@ -22,7 +22,7 @@ CONFFILE = os.path.join(BASEDIR, 'config.ini')
 COINSFILE = os.path.join(BASEDIR, 'coins.list')
 LOGOFILE = os.path.join(BASEDIR, 'logo.uni')
 CONFIG = configparser.ConfigParser()
-TOTUIVERSION = "TOTUI v1.7.5"
+TOTUIVERSION = "TOTUI v1.7.6"
 
 def read_configuration(confpath):
     """Read the configuration file at given path."""
@@ -94,6 +94,7 @@ class WithdrawCoin(npyscreen.ActionForm):
     two_factor_authentication = ''
     Togre = None
     prevCoin = ''
+    balances = []
     
     def getBalances(self):
         
@@ -119,10 +120,10 @@ class WithdrawCoin(npyscreen.ActionForm):
         
         self.Togre = TradeOgreAPI(CONFIG['api'].get('pub_key',''), CONFIG['api'].get('secret_key',''))
 
-        balances = self.getBalances()
+        self.balances = self.getBalances()
         
-        self.CoinBalances = self.add(BoxTitle, name="Available Coin Balances", values = balances,
-                            max_height=self.y - 40, width = 25, rely = 5, relx = 36,
+        self.CoinBalances = self.add(BoxTitle, name="Available Coin Balances", values = self.balances,
+                            max_height=self.y - 40, width = 38, rely = 5, relx = 36,
                             scroll_exit = True,
                             contained_widget_arguments={
                                 'color': "WARNING", 
@@ -168,9 +169,13 @@ class WithdrawCoin(npyscreen.ActionForm):
                 self.wallet_status.value = "Wallet (%s): %s " % (self.coin.value,  wStatus)
                 self.wallet_status.display()
                 self.prevCoin = self.coin.value  
-                
-        if self.CoinBalances.value[0]:
-            self.coin.value, self.amount.value = self.CoinBalances.value[0].split(' ')
+        try:
+            if self.CoinBalances.value[0] >= 0:
+                self.coin.value, self.amount.value = re.split(' +',self.balances[self.CoinBalances.value[0]])
+                self.coin.display()
+                self.amount.display()
+        except IndexError:
+            pass
         
     def change_forms(self, *args, **keywords):    
         change_to = "MAIN"
@@ -203,8 +208,13 @@ class GetCoinDepositAddress(npyscreen.ActionForm):
         self.coin   = self.add(npyscreen.TitleText, name = "Coin: ", value="", use_two_lines = False, begin_entry_at = 7)
     
     def while_waiting(self):
-        self.coin.value = self.CoinList.value[0]
-    
+        try:
+            if self.CoinList.value[0] >= 0:
+                self.coin.value = TS.coins[self.CoinList.value[0]]
+                self.coin.display()
+            
+        except IndexError:
+            pass
     def on_ok(self):
         global TS
         global CONFIG
